#!/usr/bin/zsh

# Author: Matthias Mairleitner
# Date: So 04 Sep 2022 08:54:01
# Description: custom user config for encapsulating oh-my-sh configuration
#
# Enable Powerlevel10k instant prompt. Should stay close to the top of ~/.zshrc.
# Initialization code that may require console input (password prompts, [y/n]
# confirmations, etc.) must go above this block; everything else may go below.
if [[ -r "${XDG_CACHE_HOME:-$HOME/.cache}/p10k-instant-prompt-${(%):-%n}.zsh" ]]; then
  source "${XDG_CACHE_HOME:-$HOME/.cache}/p10k-instant-prompt-${(%):-%n}.zsh"
fi

DO_NOT_USE_OH_MY_ZSH=false

# Determine terminal capabilities.
{
    if ! zmodload zsh/langinfo zsh/terminfo ||
        [[ $langinfo[CODESET] != (utf|UTF)(-|)8 || $TERM == (dumb|linux) ]] ||
        (( terminfo[colors] < 256 )); then
            # Don't use the powerline config. It won't work on this terminal.
            local DO_NOT_USE_OH_MY_ZSH=true
            # Define alias `x` if our parent process is `login`.
            local parent
            if { parent=$(</proc/$PPID/comm) } && [[ ${parent:t} == login ]]; then
                alias x='startx ~/.xinitrc'
            fi
    fi
} 2>/dev/null

############################################
# oh-my-zsh

if [[ $DO_NOT_USE_OH_MY_ZSH == true ]]; then
    exit 0
fi

# Use 256 colors and UNICODE.
export ZSH=$HOME/.oh-my-zsh

# see: https://github.com/romkatv/powerlevel10k/blob/master/powerlevel10k.zsh-theme
ZSH_THEME="powerlevel10k/powerlevel10k"

#plugins=(git)

source $ZSH/oh-my-zsh.sh

# To customize prompt, run `p10k configure` or edit ~/.p10k.zsh.
[[ ! -f ~/.p10k.zsh ]] || source ~/.p10k.zsh

